@@ -28,7 +28,7 @@
 #' POST("http://httpbin.org/delete")
 DELETE <- function(url = NULL, config = list(), ..., handle = NULL) {
   hu <- handle_url(handle, url, ...)
-  config <- make_config(config, ..., list(nobody = 1L))
+  config <- make_config(config, ...)
 
   make_request("delete", hu$handle, hu$url, config)
 }
